<p align="center" style="margin-bottom: 0;"><img src="https://github.com/VaidikKhurana/prvict/blob/master/src/prvict/assets/icons/prvict-logo-sideways.png" width="230" alt="Prvict Logo"></p>
<div align="center" style="margin-top: 0;">

<div align="center">
<b>A library pioneering tech solutions.</b>
</div>
<br>

[![github](https://img.shields.io/badge/-grey?logo=github)](https://github.com/VaidikKhurana/prvict)
[![yt](https://img.shields.io/badge/-grey?logo=youtube)](https://www.youtube.com/@VaidikKhurana)
[![pypi](https://img.shields.io/badge/-grey?logo=python&logoColor=white)](https://google.com)
![Discord](https://img.shields.io/badge/-grey?logo=discord&logoColor=white)

</div>

***
An open-source project consisting of algorithms, programs, and tech solutions for future innovations and implications. The PRVICT project is a group of programmers building solutions through computational means by solving each and every problem through the medium of technology. **We have the goal of revolutionizing technology and using it for the betterment of the world. Our primary objective is to work, improvise, and optimize artificial intelligence for multiple use cases with both commercial and private implications**.

Our algorithms consist of expert logical and analytical functions, allowing them to be efficient in every use. We plan on developing the world's best AIs by changing today's architecture of creating AI. In the future, the project will scale to multiple AI models for many use cases. This may include LLM's, image recognition, computer vision, and many more.
                                  V 0.8.3
***
